
var Cc = Components.classes;
var Ci = Components.interfaces;

// Datasource session object

function NoteSession() {
  this.init();
}

NoteSession.prototype = {
  config_file : "notetaker.rdf",
  datasource : null,
  init : function (otherfile) {
    var fdir, conv, rdf, file, url;

    if (otherfile) this.config_file = otherfile;

    with (window) {
      fdir = Cc["@mozilla.org/file/directory_service;1"];
      fdir = fdir.getService(Ci.nsIProperties);

      conv = Cc["@mozilla.org/network/protocol;1?name=file"];
      conv = conv.createInstance(Ci.nsIFileProtocolHandler);

      rdf  = Cc["@mozilla.org/rdf/rdf-service;1"];
      rdf  = rdf.getService(Ci.nsIRDFService);
    }

    file = fdir.get("ProfD", Ci.nsIFile);
    file.append(this.config_file);

    if (!file.exists())
      throw this.config_file + " is missing";

    if (!file.isFile() || !file.isWritable() || !file.isReadable())
      throw this.config_file + " has type or permission problems";

    url  = conv.newFileURI(file);
    this.datasource = rdf.GetDataSourceBlocking(url.spec);
  }
};

// one note constructor

function Note() {
}

Note.prototype = {
  url : null,
  summary : "",
  details : "",
  chop_query : true, home_page : false,
  width : 100, height : 100, top : 100, left : 100,
  clear : function () {
    this.url = null;
  },
  resolve : function (url) {

    var ds = window.noteSession.datasource;
    var ns = "http://www.mozilla.org/notetaker-rdf#";

    // The simplest solution (a one fact query) is to use
    // nsIRDFDataSource.GetTarget() to test the existence of this fact:
    // <- url, http://www.mozilla.org/notetaker-rdf#summary, ?target ->

    // Instead, we illustrate use of sequences by testing for
    // 'url' membership of the <Seq> named urn:notetaker:notes

    var rdf = Cc["@mozilla.org/rdf/rdf-service;1"];
        rdf = rdf.getService(Ci.nsIRDFService);

    var container = Cc["@mozilla.org/rdf/container;1"];
        container = container.getService(Ci.nsIRDFContainer);

    var cu = Cc["@mozilla.org/rdf/container-utils;1"];
        cu = cu.getService(Ci.nsIRDFContainerUtils);

    var seq_node     = rdf.GetResource("urn:notetaker:notes");
    var url_node     = rdf.GetResource(url);
    var chopped_node = rdf.GetResource(url.replace(/\?.*/,""));

    var matching_node, prop_node, value_node;
    
    if (!cu.IsContainer(ds,seq_node)) {
      throw "Missing <Seq> 'urn:notetaker:notes' in " + noteSession.config_file;
      return;
    }
    container.Init(ds,seq_node);

    // Try the full URL first, then the chopped URL, then give up

    if ( container.IndexOf(url_node) != -1) {
      matching_node = url_node;
      this.url = url;
      this.chop_query = false;
    }
    else if ( container.IndexOf(chopped_node) != -1 ) {  
      matching_node = chopped_node;
      this.url = url.replace(/\?.*/,"");
    }
    else {
      this.url = null;
      return;
    }

    // Something found; grab all the note properties for it.
    
    var props = ["summary", "details", "width", "height", "top", "left"];

    for (var i=0; i<props.length; i++)
    {
      pred_node  = rdf.GetResource(ns + props[i]);
      value_node = ds.GetTarget(matching_node, pred_node, true);
      value_node = value_node.QueryInterface(Ci.nsIRDFLiteral);
      this[props[i]] = value_node.Value;
    }
  }
}

// order is important
var noteSession = new NoteSession();
var note = new Note();

// test case
note.resolve("http://saturn/test1.html");

